@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 """
 `.ServerInterface` is an interface to override for server support.
@@ -29,10 +29,9 @@ from paramiko.common import (
     AUTH_FAILED,
     AUTH_SUCCESSFUL,
 )
-from paramiko.py3compat import string_types
 
 
-class ServerInterface(object):
+class ServerInterface:
     """
     This class defines an interface for controlling the behavior of Paramiko
     in server mode.
@@ -226,7 +225,7 @@ class ServerInterface(object):
 
         The default implementation always returns ``AUTH_FAILED``.
 
-        :param list responses: list of `str` responses from the client
+        :param responses: list of `str` responses from the client
         :return:
             ``AUTH_FAILED`` if the authentication fails; ``AUTH_SUCCESSFUL`` if
             it succeeds; ``AUTH_PARTIALLY_SUCCESSFUL`` if the interactive auth
@@ -356,7 +355,7 @@ class ServerInterface(object):
         If the request was successful and you would like to return contextual
         data to the remote host, return a tuple.  Items in the tuple will be
         sent back with the successful result.  (Note that the items in the
-        tuple can only be strings, ints, longs, or bools.)
+        tuple can only be strings, ints, or bools.)
 
         The default implementation always returns ``False``, indicating that it
         does not support any global requests.
@@ -594,7 +593,7 @@ class ServerInterface(object):
         return (None, None)
 
 
-class InteractiveQuery(object):
+class InteractiveQuery:
     """
     A query (set of prompts) for a user during interactive authentication.
     """
@@ -615,7 +614,7 @@ class InteractiveQuery(object):
         self.instructions = instructions
         self.prompts = []
         for x in prompts:
-            if isinstance(x, string_types):
+            if isinstance(x, str):
                 self.add_prompt(x)
             else:
                 self.add_prompt(x[0], x[1])
@@ -678,13 +677,13 @@ class SubsystemHandler(threading.Thread):
     def _run(self):
         try:
             self.__transport._log(
-                DEBUG, "Starting handler for subsystem %s" % self.__name
+                DEBUG, "Starting handler for subsystem {}".format(self.__name)
             )
             self.start_subsystem(self.__name, self.__transport, self.__channel)
         except Exception as e:
             self.__transport._log(
                 ERROR,
-                'Exception in subsystem handler for "{0}": {1}'.format(
+                'Exception in subsystem handler for "{}": {}'.format(
                     self.__name, e
                 ),
             )
