@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 
 from binascii import hexlify
@@ -28,7 +28,6 @@ from paramiko import util
 from paramiko.channel import Channel
 from paramiko.message import Message
 from paramiko.common import INFO, DEBUG, o777
-from paramiko.py3compat import b, u, long
 from paramiko.sftp import (
     BaseSFTP,
     CMD_OPENDIR,
@@ -61,12 +60,13 @@ from paramiko.sftp import (
     SFTP_EOF,
     SFTP_NO_SUCH_FILE,
     SFTP_PERMISSION_DENIED,
+    int64,
 )
 
 from paramiko.sftp_attr import SFTPAttributes
 from paramiko.ssh_exception import SSHException
 from paramiko.sftp_file import SFTPFile
-from paramiko.util import ClosingContextManager
+from paramiko.util import ClosingContextManager, b, u
 
 
 def _to_unicode(s):
@@ -179,7 +179,7 @@ class SFTPClient(BaseSFTP, ClosingContextManager):
             # escape '%' in msg (they could come from file or directory names)
             # before logging
             msg = msg.replace("%", "%%")
-            super(SFTPClient, self)._log(
+            super()._log(
                 level,
                 "[chan %s] " + msg,
                 *([self.sock.get_name()] + list(args))
@@ -828,7 +828,7 @@ class SFTPClient(BaseSFTP, ClosingContextManager):
             msg = Message()
             msg.add_int(self.request_number)
             for item in arg:
-                if isinstance(item, long):
+                if isinstance(item, int64):
                     msg.add_int64(item)
                 elif isinstance(item, int):
                     msg.add_int(item)
