@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 """
 Server-mode SFTP support.
@@ -32,12 +32,13 @@ from paramiko.sftp import (
     SFTP_FAILURE,
     SFTP_PERMISSION_DENIED,
     SFTP_NO_SUCH_FILE,
+    int64,
 )
 from paramiko.sftp_si import SFTPServerInterface
 from paramiko.sftp_attr import SFTPAttributes
 from paramiko.common import DEBUG
-from paramiko.py3compat import long, string_types, bytes_types, b
 from paramiko.server import SubsystemHandler
+from paramiko.util import b
 
 
 # known hash algorithms for the "check-file" extension
@@ -128,17 +129,13 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
     def _log(self, level, msg):
         if issubclass(type(msg), list):
             for m in msg:
-                super(SFTPServer, self)._log(
-                    level, "[chan " + self.sock.get_name() + "] " + m
-                )
+                super()._log(level, "[chan " + self.sock.get_name() + "] " + m)
         else:
-            super(SFTPServer, self)._log(
-                level, "[chan " + self.sock.get_name() + "] " + msg
-            )
+            super()._log(level, "[chan " + self.sock.get_name() + "] " + msg)
 
     def start_subsystem(self, name, transport, channel):
         self.sock = channel
-        self._log(DEBUG, "Started sftp server on channel %s" % repr(channel))
+        self._log(DEBUG, "Started sftp server on channel {!r}".format(channel))
         self._send_server_version()
         self.server.session_started()
         while True:
@@ -166,7 +163,7 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
 
     def finish_subsystem(self):
         self.server.session_ended()
-        super(SFTPServer, self).finish_subsystem()
+        super().finish_subsystem()
         # close any file handles that were left open
         # (so we can return them to the OS quickly)
         for f in self.file_table.values():
@@ -228,19 +225,18 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
         msg = Message()
         msg.add_int(request_number)
         for item in arg:
-            if isinstance(item, long):
+            # NOTE: this is a very silly tiny class used for SFTPFile mostly
+            if isinstance(item, int64):
                 msg.add_int64(item)
             elif isinstance(item, int):
                 msg.add_int(item)
-            elif isinstance(item, (string_types, bytes_types)):
+            elif isinstance(item, (str, bytes)):
                 msg.add_string(item)
             elif type(item) is SFTPAttributes:
                 item._pack(msg)
             else:
                 raise Exception(
-                    "unknown type for {0!r} type {1!r}".format(
-                        item, type(item)
-                    )
+                    "unknown type for {!r} type {!r}".format(item, type(item))
                 )
         self._send_packet(t, msg)
 
@@ -249,7 +245,7 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
             # must be error code
             self._send_status(request_number, handle)
             return
-        handle._set_name(b("hx%d" % self.next_handle))
+        handle._set_name(b("hx{:d}".format(self.next_handle)))
         self.next_handle += 1
         if folder:
             self.folder_table[handle._get_name()] = handle
@@ -342,7 +338,7 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
             hash_obj = alg()
             while count < blocklen:
                 data = f.read(offset, chunklen)
-                if not isinstance(data, bytes_types):
+                if not isinstance(data, bytes):
                     self._send_status(
                         request_number, data, "Unable to hash file"
                     )
@@ -378,7 +374,7 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
         return flags
 
     def _process(self, t, request_number, msg):
-        self._log(DEBUG, "Request: %s" % CMD_NAMES[t])
+        self._log(DEBUG, "Request: {}".format(CMD_NAMES[t]))
         if t == CMD_OPEN:
             path = msg.get_text()
             flags = self._convert_pflags(msg.get_int())
@@ -410,7 +406,7 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
                 )
                 return
             data = self.file_table[handle].read(offset, length)
-            if isinstance(data, (bytes_types, string_types)):
+            if isinstance(data, (bytes, str)):
                 if len(data) == 0:
                     self._send_status(request_number, SFTP_EOF)
                 else:
@@ -502,7 +498,7 @@ class SFTPServer(BaseSFTP, SubsystemHandler):
         elif t == CMD_READLINK:
             path = msg.get_text()
             resp = self.server.readlink(path)
-            if isinstance(resp, (bytes_types, string_types)):
+            if isinstance(resp, (bytes, str)):
                 self._response(
                     request_number, CMD_NAME, 1, resp, "", SFTPAttributes()
                 )
