@@ -14,18 +14,17 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 """
 Some unit tests for the BufferedFile abstraction.
 """
 
 import unittest
-import sys
+from io import BytesIO
 
 from paramiko.common import linefeed_byte, crlf, cr_byte
 from paramiko.file import BufferedFile
-from paramiko.py3compat import BytesIO
 
 from .util import needs_builtin
 
@@ -162,15 +161,6 @@ class BufferedFileTest(unittest.TestCase):
         )
         f.close()
 
-    def test_buffering_writes(self):
-        """
-        verify that buffered objects can be written
-        """
-        if sys.version_info[0] == 2:
-            f = LoopbackFile("r+", 16)
-            f.write(buffer(b"Too small."))  # noqa
-            f.close()
-
     def test_readable(self):
         f = LoopbackFile("r")
         self.assertTrue(f.readable())
@@ -198,7 +188,7 @@ class BufferedFileTest(unittest.TestCase):
             self.assertRaises(TypeError, f.write, object())
 
     def test_write_unicode_as_binary(self):
-        text = u"\xa7 why is writing text to a binary file allowed?\n"
+        text = "\xa7 why is writing text to a binary file allowed?\n"
         with LoopbackFile("rb+") as f:
             f.write(text)
             self.assertEqual(f.read(), text.encode("utf-8"))
