@@ -14,13 +14,12 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 """
 Some unit tests for the ssh2 protocol in Transport.
 """
 
-from __future__ import with_statement
 
 from binascii import hexlify
 from contextlib import contextmanager
@@ -30,7 +29,7 @@ import time
 import threading
 import random
 import unittest
-from mock import Mock
+from unittest.mock import Mock
 
 from paramiko import (
     AuthHandler,
@@ -57,11 +56,11 @@ from paramiko.common import (
     MSG_USERAUTH_SUCCESS,
     cMSG_CHANNEL_WINDOW_ADJUST,
     cMSG_UNIMPLEMENTED,
+    byte_chr,
 )
-from paramiko.py3compat import bytes, byte_chr
 from paramiko.message import Message
 
-from .util import needs_builtin, _support, slow
+from .util import needs_builtin, _support, requires_sha1_signing, slow
 from .loop import LoopSocket
 
 
@@ -196,9 +195,9 @@ class TransportTest(unittest.TestCase):
     def test_security_options(self):
         o = self.tc.get_security_options()
         self.assertEqual(type(o), SecurityOptions)
-        self.assertTrue(("aes256-cbc", "blowfish-cbc") != o.ciphers)
-        o.ciphers = ("aes256-cbc", "blowfish-cbc")
-        self.assertEqual(("aes256-cbc", "blowfish-cbc"), o.ciphers)
+        self.assertTrue(("aes256-cbc", "aes192-cbc") != o.ciphers)
+        o.ciphers = ("aes256-cbc", "aes192-cbc")
+        self.assertEqual(("aes256-cbc", "aes192-cbc"), o.ciphers)
         try:
             o.ciphers = ("aes256-cbc", "made-up-cipher")
             self.assertTrue(False)
@@ -467,7 +466,7 @@ class TransportTest(unittest.TestCase):
         self.assertEqual([chan], r)
         self.assertEqual([], w)
         self.assertEqual([], e)
-        self.assertEqual(bytes(), chan.recv(16))
+        self.assertEqual(b"", chan.recv(16))
 
         # make sure the pipe is still open for now...
         p = chan._pipe
@@ -686,7 +685,7 @@ class TransportTest(unittest.TestCase):
         self.assertEqual(chan.send_ready(), True)
         total = 0
         K = "*" * 1024
-        limit = 1 + (64 * 2 ** 15)
+        limit = 1 + (64 * 2**15)
         while total < limit:
             chan.send(K)
             total += len(K)
@@ -874,7 +873,7 @@ class TransportTest(unittest.TestCase):
         for val, correct in [
             (4095, MIN_PACKET_SIZE),
             (None, DEFAULT_MAX_PACKET_SIZE),
-            (2 ** 32, MAX_WINDOW_SIZE),
+            (2**32, MAX_WINDOW_SIZE),
         ]:
             self.assertEqual(self.tc._sanitize_packet_size(val), correct)
 
@@ -885,7 +884,7 @@ class TransportTest(unittest.TestCase):
         for val, correct in [
             (32767, MIN_WINDOW_SIZE),
             (None, DEFAULT_WINDOW_SIZE),
-            (2 ** 32, MAX_WINDOW_SIZE),
+            (2**32, MAX_WINDOW_SIZE),
         ]:
             self.assertEqual(self.tc._sanitize_window_size(val), correct)
 
@@ -904,7 +903,7 @@ class TransportTest(unittest.TestCase):
         class SlowPacketizer(Packetizer):
             def read_message(self):
                 time.sleep(1)
-                return super(SlowPacketizer, self).read_message()
+                return super().read_message()
 
         # NOTE: prettttty sure since the replaced .packetizer Packetizer is now
         # no longer doing anything with its copy of the socket...everything'll
@@ -950,7 +949,7 @@ class TransportTest(unittest.TestCase):
         verify behaviours sending various instances to a channel
         """
         self.setup_test_server()
-        text = u"\xa7 slice me nicely"
+        text = "\xa7 slice me nicely"
         with self.tc.open_session() as chan:
             schan = self.ts.accept(1.0)
             if schan is None:
@@ -1289,6 +1288,7 @@ class TestSHA2SignatureKeyExchange(unittest.TestCase):
     # are new tests in test_pkey.py which use known signature blobs to prove
     # the SHA2 family was in fact used!
 
+    @requires_sha1_signing
     def test_base_case_ssh_rsa_still_used_as_fallback(self):
         # Prove that ssh-rsa is used if either, or both, participants have SHA2
         # algorithms disabled
@@ -1411,6 +1411,7 @@ class TestSHA2SignaturePubkeys(unittest.TestCase):
         ) as (tc, ts, err):
             assert isinstance(err, AuthenticationException)
 
+    @requires_sha1_signing
     def test_ssh_rsa_still_used_when_sha2_disabled(self):
         privkey = RSAKey.from_private_key_file(_support("test_rsa.key"))
         # NOTE: this works because key obj comparison uses public bytes
