@@ -14,14 +14,13 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
 
 """
 Some unit tests for utility functions.
 """
 
 from binascii import hexlify
-import errno
 import os
 from hashlib import sha1
 import unittest
@@ -29,7 +28,6 @@ import unittest
 import paramiko
 import paramiko.util
 from paramiko.util import safe_string
-from paramiko.py3compat import byte_ord
 
 
 test_hosts_file = """\
@@ -87,12 +85,12 @@ class UtilTest(unittest.TestCase):
             assert name in paramiko.__all__
 
     def test_generate_key_bytes(self):
-        x = paramiko.util.generate_key_bytes(
+        key_bytes = paramiko.util.generate_key_bytes(
             sha1, b"ABCDEFGH", "This is my secret passphrase.", 64
         )
-        hex = "".join(["%02x" % byte_ord(c) for c in x])
+        hexy = "".join([f"{byte:02x}" for byte in key_bytes])
         hexpected = "9110e2f6793b69363e58173e9436b13a5a4b339005741d5c680e505f57d871347b4239f14fb5c46e857d5e100424873ba849ac699cea98d729e57b3e84378e8b"  # noqa
-        assert hex == hexpected
+        assert hexy == hexpected
 
     def test_host_keys(self):
         with open("hostfile.temp", "w") as f:
@@ -109,39 +107,6 @@ class UtilTest(unittest.TestCase):
         finally:
             os.unlink("hostfile.temp")
 
-    def test_eintr_retry(self):
-        assert "foo" == paramiko.util.retry_on_signal(lambda: "foo")
-
-        # Variables that are set by raises_intr
-        intr_errors_remaining = [3]
-        call_count = [0]
-
-        def raises_intr():
-            call_count[0] += 1
-            if intr_errors_remaining[0] > 0:
-                intr_errors_remaining[0] -= 1
-                raise IOError(errno.EINTR, "file", "interrupted system call")
-
-        self.assertTrue(paramiko.util.retry_on_signal(raises_intr) is None)
-        assert 0 == intr_errors_remaining[0]
-        assert 4 == call_count[0]
-
-        def raises_ioerror_not_eintr():
-            raise IOError(errno.ENOENT, "file", "file not found")
-
-        self.assertRaises(
-            IOError,
-            lambda: paramiko.util.retry_on_signal(raises_ioerror_not_eintr),
-        )
-
-        def raises_other_exception():
-            raise AssertionError("foo")
-
-        self.assertRaises(
-            AssertionError,
-            lambda: paramiko.util.retry_on_signal(raises_other_exception),
-        )
-
     def test_clamp_value(self):
         assert 32768 == paramiko.util.clamp_value(32767, 32768, 32769)
         assert 32767 == paramiko.util.clamp_value(32767, 32765, 32769)
